@@ -41,8 +41,6 @@
 
 #define KWINDOWSYSTEM_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KWINDOWSYSTEM_NO_DEPRECATED) && !defined(KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED
-#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED_WARNINGS
 #  define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KWINDOWSYSTEM_DEPRECATED
-#  define KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
